@@ -17,16 +17,13 @@
 #'  When you [`tidy()`][tidy.recipe()] this check, a tibble with columns
 #'  `terms` (the selectors or variables selected) and `value` (the type)
 #'  is returned.
-#' @examples
-#'
-#' library(modeldata)
-#' data(biomass)
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(biomass, package = "modeldata")
 #'
 #' biomass_rec <- recipe(HHV ~ ., data = biomass) %>%
-#'    step_rm(sample, dataset) %>%
-#'    check_cols(contains("gen")) %>%
-#'    step_center(all_numeric_predictors())
-#'
+#'   step_rm(sample, dataset) %>%
+#'   check_cols(contains("gen")) %>%
+#'   step_center(all_numeric_predictors())
 #' \dontrun{
 #' bake(biomass_rec, biomass[, c("carbon", "HHV")])
 #' }
@@ -40,8 +37,8 @@ check_cols <-
     add_check(
       recipe,
       check_cols_new(
-        terms   = enquos(...),
-        role    = role,
+        terms = enquos(...),
+        role = role,
         trained = trained,
         columns = NULL,
         skip = skip,
@@ -52,22 +49,25 @@ check_cols <-
 
 check_cols_new <-
   function(terms, role, trained, columns, skip, id) {
-    check(subclass = "cols",
-          prefix   = "check_",
-          terms    = terms,
-          role     = role,
-          trained  = trained,
-          columns  = columns,
-          skip     = skip,
-          id       = id)
+    check(
+      subclass = "cols",
+      prefix = "check_",
+      terms = terms,
+      role = role,
+      trained = trained,
+      columns = columns,
+      skip = skip,
+      id = id
+    )
   }
 
+#' @export
 prep.check_cols <- function(x, training, info = NULL, ...) {
   col_names <- recipes_eval_select(x$terms, training, info)
 
   check_cols_new(
     terms = x$terms,
-    role  = x$role,
+    role = x$role,
     trained = TRUE,
     columns = col_names,
     skip = x$skip,
@@ -75,18 +75,19 @@ prep.check_cols <- function(x, training, info = NULL, ...) {
   )
 }
 
+#' @export
 bake.check_cols <- function(object, new_data, ...) {
   original_cols <- object$columns
-  new_cols      <- names(new_data)
+  new_cols <- names(new_data)
   missing <- setdiff(original_cols, new_cols)
   if (length(missing) > 0) {
     mis_cols <- paste(paste0("`", missing, "`"), collapse = ", ")
     rlang::abort(
       paste0(
         "The following cols are missing from `new_data`: ",
-         mis_cols,
+        mis_cols,
         "."
-        )
+      )
     )
   }
   new_data
@@ -110,4 +111,3 @@ tidy.check_cols <- function(x, ...) {
   res$id <- x$id
   res
 }
-
