@@ -1,9 +1,8 @@
 #' Handle levels in multiple predictors together
 #'
-#' `step_dummy_multi_choice()` creates a *specification* of a recipe
-#'  step that will convert multiple nominal data (e.g. character or factors)
-#'  into one or more numeric binary model terms for the levels of
-#'  the original data.
+#' `step_dummy_multi_choice()` creates a *specification* of a recipe step that
+#' will convert multiple nominal data (e.g. characters or factors) into one or
+#' more numeric binary model terms for the levels of the original data.
 #'
 #' @inheritParams step_dummy
 #' @inheritParams step_center
@@ -164,7 +163,6 @@ multi_dummy_check_type <- function(dat) {
 #' @export
 bake.step_dummy_multi_choice <- function(object, new_data, ...) {
   col_names <- object$input
-
   check_new_data(col_names, object, new_data)
 
   indicators <- multi_dummy(new_data[, col_names], object$levels)
@@ -180,12 +178,8 @@ bake.step_dummy_multi_choice <- function(object, new_data, ...) {
 
   indicators <- check_name(indicators, new_data, object, names(indicators))
 
-  new_data <- bind_cols(new_data, indicators)
-  keep_original_cols <- get_keep_original_cols(object)
-
-  if (!keep_original_cols) {
-    new_data <- new_data[, !(colnames(new_data) %in% col_names), drop = FALSE]
-  }
+  new_data <- vec_cbind(new_data, indicators)
+  new_data <- remove_original_cols(new_data, object, col_names)
 
   new_data
 }
