@@ -1,8 +1,7 @@
 #' Create Interaction Variables
 #'
-#' `step_interact` creates a *specification* of a recipe
-#'  step that will create new columns that are interaction terms
-#'  between two or more variables.
+#' `step_interact()` creates a *specification* of a recipe step that will create
+#' new columns that are interaction terms between two or more variables.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -88,16 +87,18 @@ step_interact <-
            trained = FALSE,
            objects = NULL,
            sep = "_x_",
+           keep_original_cols = TRUE,
            skip = FALSE,
            id = rand_id("interact")) {
     add_step(
       recipe,
       step_interact_new(
-        terms = terms,
+        terms = enquos(terms),
         trained = trained,
         role = role,
         objects = objects,
         sep = sep,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -106,7 +107,7 @@ step_interact <-
 
 ## Initializes a new object
 step_interact_new <-
-  function(terms, role, trained, objects, sep, skip, id) {
+  function(terms, role, trained, objects, sep, keep_original_cols, skip, id) {
     step(
       subclass = "interact",
       terms = terms,
@@ -114,6 +115,7 @@ step_interact_new <-
       trained = trained,
       objects = objects,
       sep = sep,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -124,9 +126,41 @@ step_interact_new <-
 ## one large set of collected terms.
 #' @export
 prep.step_interact <- function(x, training, info = NULL, ...) {
+
+  # Empty selection
+  if (identical(x$terms[[1]], quo())) {
+    return(
+        step_interact_new(
+        terms = x$terms,
+        role = x$role,
+        trained = TRUE,
+        objects = x$objects,
+        sep = x$sep,
+        keep_original_cols = x$keep_original_cols,
+        skip = x$skip,
+        id = x$id
+      )
+    )
+  }
+
+  # make backwards compatible with 1.0.6 (#1138)
+  if (!is_formula(x)) {
+    tmp_terms <- rlang::as_label(x$terms[[1]])
+    if (substr(tmp_terms, 1, 1) == "~") {
+      tmp_terms <- as.formula(tmp_terms)
+    } else {
+      tmp_terms <- rlang::eval_tidy(x$terms[[1]])
+      if (!is_formula(tmp_terms)) {
+        rlang::abort("`term` must be a formula.")
+      }
+    }
+
+    environment(tmp_terms) <- environment(x$terms[[1]])
+    x$terms <- tmp_terms
+  }
+
   # Identify any selectors that are involved in the interaction
   # formula
-
   form_sel <- find_selectors(x$terms)
 
   # Use formula environment as quosure env
@@ -190,6 +224,7 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
     trained = TRUE,
     objects = int_terms,
     sep = x$sep,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -198,6 +233,12 @@ prep.step_interact <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_interact <- function(object, new_data, ...) {
+
+  # empty selection
+  if (is.null(object$objects)) {
+    return(new_data)
+  }
+
   col_names <- unlist(lapply(object$objects, function(x) all.vars(rlang::f_rhs(x))))
   check_new_data(col_names, object, new_data)
 
@@ -234,7 +275,8 @@ bake.step_interact <- function(object, new_data, ...) {
     gsub(":", object$sep, unlist(lapply(res, colnames)))
   out <- as_tibble(out)
   out <- check_name(out, new_data, object, names(out))
-  new_data <- bind_cols(new_data, out)
+  new_data <- vec_cbind(new_data, out)
+  new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
@@ -300,7 +342,17 @@ make_small_terms <- function(forms, dat) {
 print.step_interact <-
   function(x, width = max(20, options()$width - 27), ...) {
     title <- "Interactions with "
-    terms <- as.character(x$terms)[-1]
+
+    if (x$trained) {
+      terms <- as.character(x$terms)[-1]
+    } else {
+      terms <- as_label(x$terms[[1]])
+      if (terms == "<empty>") {
+        terms <- ""
+      } else {
+        terms <- as.character(as.formula(terms))[-1]
+      }
+    }
     untrained_terms <- rlang::parse_quos(terms, rlang::current_env())
     print_step(terms, untrained_terms, x$trained, title, width)
     invisible(x)
