@@ -1,11 +1,10 @@
 #' Add intercept (or constant) column
 #'
-#' `step_intercept` creates a *specification* of a recipe step that
-#'   will add an intercept or constant term in the first column of a data
-#'   matrix. `step_intercept` has defaults to *predictor* role so
-#'   that it is by default called in the bake step. Be careful to avoid
-#'   unintentional transformations when calling steps with
-#'   `all_predictors`.
+#' `step_intercept()` creates a *specification* of a recipe step that will add
+#' an intercept or constant term in the first column of a data matrix.
+#' `step_intercept()` defaults to *predictor* role so that it is by default
+#' only called in the bake step. Be careful to avoid unintentional transformations
+#' when calling steps with `all_predictors()`.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -94,7 +93,7 @@ prep.step_intercept <- function(x, training, info = NULL, ...) {
 bake.step_intercept <- function(object, new_data, ...) {
   intercept <- tibble(!!object$name := rep(object$value, nrow(new_data)))
   intercept <- check_name(intercept, new_data, object, names(intercept))
-  new_data <- bind_cols(intercept, new_data)
+  new_data <- vec_cbind(intercept, new_data)
   new_data
 }
 
