@@ -1,8 +1,8 @@
 #' Kernel PCA Signal Extraction
 #'
-#' `step_kpca` creates a *specification* of a recipe step that
-#'  will convert numeric data into one or more principal components
-#'  using a kernel basis expansion.
+#' `step_kpca()` creates a *specification* of a recipe step that will convert
+#' numeric data into one or more principal components using a kernel basis
+#' expansion.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -12,8 +12,6 @@
 #'  (or at all).
 #' @param res An S4 [kernlab::kpca()] object is stored here once this
 #'  preprocessing step has be trained by [prep()].
-#' @param columns A character string of variable names that will
-#'  be populated elsewhere.
 #' @template step-return
 #' @family multivariate transformation steps
 #' @export
@@ -152,29 +150,28 @@ prep.step_kpca <- function(x, training, info = NULL, ...) {
 #' @export
 bake.step_kpca <- function(object, new_data, ...) {
   uses_dim_red(object)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  if (object$num_comp > 0 && length(object$columns) > 0) {
-    check_new_data(object$columns, object, new_data)
-
-    cl <-
-      rlang::call2(
-        "predict",
-        .ns = "kernlab",
-        object = object$res,
-        rlang::expr(as.matrix(new_data[, object$columns]))
-      )
-    comps <- rlang::eval_tidy(cl)
-    comps <- comps[, seq_len(object$num_comp), drop = FALSE]
-    colnames(comps) <- names0(ncol(comps), object$prefix)
-    comps <- as_tibble(comps)
-    comps <- check_name(comps, new_data, object)
-    new_data <- bind_cols(new_data, comps)
-    keep_original_cols <- get_keep_original_cols(object)
-
-    if (!keep_original_cols) {
-      new_data <- new_data[, !(colnames(new_data) %in% object$columns), drop = FALSE]
-    }
+  keep_going <- object$num_comp > 0 && length(col_names) > 0
+  if (!keep_going) {
+    return(new_data)
   }
+
+  cl <-
+    rlang::call2(
+      "predict",
+      .ns = "kernlab",
+      object = object$res,
+      rlang::expr(as.matrix(new_data[, col_names]))
+    )
+  comps <- rlang::eval_tidy(cl)
+  comps <- comps[, seq_len(object$num_comp), drop = FALSE]
+  colnames(comps) <- names0(ncol(comps), object$prefix)
+  comps <- as_tibble(comps)
+  comps <- check_name(comps, new_data, object)
+  new_data <- vctrs::vec_cbind(new_data, comps)
+  new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
