@@ -1,8 +1,8 @@
 #' Center and scale numeric data
 #'
-#' `step_normalize` creates a *specification* of a recipe
-#'  step that will normalize numeric data to have a standard
-#'  deviation of one and a mean of zero.
+#' `step_normalize()` creates a *specification* of a recipe step that will
+#' normalize numeric data to have a standard deviation of one and a mean of
+#' zero.
 #'
 #' @inheritParams step_center
 #' @param means A named numeric vector of means. This is `NULL` until computed
@@ -151,13 +151,16 @@ prep.step_normalize <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_normalize <- function(object, new_data, ...) {
-  check_new_data(names(object$means), object, new_data)
+  col_names <- names(object$means)
+  check_new_data(col_names, object, new_data)
 
-  for (column in names(object$means)) {
-    mean <- object$means[column]
-    sd <- object$sds[column]
-    new_data[[column]] <- (new_data[[column]] - mean) / sd
+  for (col_name in col_names) {
+    mean <- object$means[col_name]
+    sd <- object$sds[col_name]
+
+    new_data[[col_name]] <- (new_data[[col_name]] - mean) / sd
   }
+
   new_data
 }
 
