@@ -1,8 +1,7 @@
 #' Near-Zero Variance Filter
 #'
-#' `step_nzv` creates a *specification* of a recipe step
-#'  that will potentially remove variables that are highly sparse
-#'  and unbalanced.
+#' `step_nzv()` creates a *specification* of a recipe step that will potentially
+#' remove variables that are highly sparse and unbalanced.
 #'
 #' @inheritParams step_center
 #' @param freq_cut,unique_cut Numeric parameters for the filtering process. See
@@ -167,9 +166,7 @@ prep.step_nzv <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_nzv <- function(object, new_data, ...) {
-  if (length(object$removals) > 0) {
-    new_data <- new_data[, !(colnames(new_data) %in% object$removals)]
-  }
+  new_data <- recipes_remove_cols(new_data, object)
   new_data
 }
 
