@@ -1,8 +1,7 @@
 #' Orthogonal Polynomial Basis Functions
 #'
-#' `step_poly` creates a *specification* of a recipe
-#'  step that will create new columns that are basis expansions of
-#'  variables using orthogonal polynomials.
+#' `step_poly()` creates a *specification* of a recipe step that will create new
+#' columns that are basis expansions of variables using orthogonal polynomials.
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -64,6 +63,7 @@ step_poly <-
            objects = NULL,
            degree = 2,
            options = list(),
+           keep_original_cols = FALSE,
            skip = FALSE,
            id = rand_id("poly")) {
     if (!is_tune(degree)) {
@@ -89,6 +89,7 @@ step_poly <-
         objects = objects,
         degree = degree,
         options = options,
+        keep_original_cols = keep_original_cols,
         skip = skip,
         id = id
       )
@@ -96,7 +97,8 @@ step_poly <-
   }
 
 step_poly_new <-
-  function(terms, role, trained, objects, degree, options, skip, id) {
+  function(terms, role, trained, objects, degree, options, keep_original_cols,
+           skip, id) {
     step(
       subclass = "poly",
       terms = terms,
@@ -105,6 +107,7 @@ step_poly_new <-
       objects = objects,
       degree = degree,
       options = options,
+      keep_original_cols = keep_original_cols,
       skip = skip,
       id = id
     )
@@ -144,6 +147,7 @@ prep.step_poly <- function(x, training, info = NULL, ...) {
     objects = obj,
     degree = x$degree,
     options = x$options,
+    keep_original_cols = get_keep_original_cols(x),
     skip = x$skip,
     id = x$id
   )
@@ -158,11 +162,10 @@ bake.step_poly <- function(object, new_data, ...) {
   # Start with n-row, 0-col tibble for the empty selection case
   new_tbl <- tibble::new_tibble(x = list(), nrow = nrow(new_data))
 
-  for (i in seq_along(col_names)) {
-    i_col_name <- col_names[[i]]
-    i_col <- new_data[[i_col_name]]
-    i_object <- object$objects[[i]]
-    i_new_names <- new_names[[i]]
+  for (col_name in col_names) {
+    i_col <- new_data[[col_name]]
+    i_object <- object$objects[[col_name]]
+    i_new_names <- new_names[[col_name]]
 
     new_cols <- predict(i_object, i_col)
     colnames(new_cols) <- i_new_names
@@ -172,8 +175,8 @@ bake.step_poly <- function(object, new_data, ...) {
   }
 
   new_tbl <- check_name(new_tbl, new_data, object, names(new_tbl))
-  new_data <- bind_cols(new_data, new_tbl)
-  new_data <- dplyr::select(new_data, -dplyr::all_of(col_names))
+  new_data <- vec_cbind(new_data, new_tbl)
+  new_data <- remove_original_cols(new_data, object, col_names)
   new_data
 }
 
