@@ -1,7 +1,8 @@
 #' Rename multiple columns using dplyr
 #'
-#' `step_rename_at` creates a *specification* of a recipe step that will rename
-#' the selected variables using a common function via [dplyr::rename_at()].
+#' `step_rename_at()` creates a *specification* of a recipe step that will
+#' rename the selected variables using a common function via
+#' [dplyr::rename_at()].
 #'
 #' @inheritParams step_pca
 #' @inheritParams step_center
@@ -16,26 +17,26 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with columns
 #' `terms` which contains the columns being transformed is returned.
+#'
+#' @template case-weights-not-supported
+#'
 #' @family dplyr steps
 #' @export
 #' @examples
 #' library(dplyr)
-#' recipe(~ ., data = iris) %>%
+#' recipe(~., data = iris) %>%
 #'   step_rename_at(everything(), fn = ~ gsub(".", "_", ., fixed = TRUE)) %>%
 #'   prep() %>%
 #'   bake(new_data = NULL) %>%
 #'   slice(1:10)
 #' @export
-step_rename_at <- function(
-  recipe, ...,
-  fn,
-  role = "predictor",
-  trained = FALSE,
-  inputs = NULL,
-  skip = FALSE,
-  id = rand_id("rename_at")
-) {
-
+step_rename_at <- function(recipe, ...,
+                           fn,
+                           role = "predictor",
+                           trained = FALSE,
+                           inputs = NULL,
+                           skip = FALSE,
+                           id = rand_id("rename_at")) {
   add_step(
     recipe,
     step_rename_at_new(
@@ -103,4 +104,3 @@ tidy.step_rename_at <- function(x, ...) {
   res$id <- x$id
   res
 }
-
