@@ -1,7 +1,7 @@
 #' General Variable Filter
 #'
-#' `step_rm` creates a *specification* of a recipe step
-#'  that will remove variables based on their name, type, or role.
+#' `step_rm()` creates a *specification* of a recipe step that will remove
+#' selected variables.
 #'
 #' @inheritParams step_center
 #' @param removals A character string that contains the names of
@@ -15,16 +15,19 @@
 #'
 #' When you [`tidy()`][tidy.recipe()] this step, a tibble with column
 #' `terms` (the columns that will be removed) is returned.
+#'
+#' @template case-weights-not-supported
+#'
 #' @family variable filter steps
 #' @export
-#' @examples
-#' library(modeldata)
-#' data(biomass)
+#' @examplesIf rlang::is_installed("modeldata")
+#' data(biomass, package = "modeldata")
 #'
 #' biomass_tr <- biomass[biomass$dataset == "Training", ]
 #' biomass_te <- biomass[biomass$dataset == "Testing", ]
 #'
-#' rec <- recipe(HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
+#' rec <- recipe(
+#'   HHV ~ carbon + hydrogen + oxygen + nitrogen + sulfur,
 #'   data = biomass_tr
 #' )
 #'
@@ -86,10 +89,8 @@ prep.step_rm <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_rm <- function(object, new_data, ...) {
-  if (length(object$removals) > 0) {
-    new_data <- new_data[, !(colnames(new_data) %in% object$removals)]
-  }
-  as_tibble(new_data)
+  new_data <- recipes_remove_cols(new_data, object)
+  new_data
 }
 
 print.step_rm <-
