@@ -1,8 +1,7 @@
 #' Sample rows using dplyr
 #'
-#' `step_sample` creates a *specification* of a recipe step
-#'  that will sample rows using [dplyr::sample_n()] or
-#'  [dplyr::sample_frac()].
+#' `step_sample()` creates a *specification* of a recipe step that will sample
+#' rows using [dplyr::sample_n()] or [dplyr::sample_frac()].
 #'
 #' @template row-ops
 #' @inheritParams step_center
@@ -51,7 +50,8 @@
 #'
 #' bake(smaller_cars, new_data = NULL) %>% nrow()
 #' bake(smaller_cars, new_data = mtcars %>% slice(21:32)) %>% nrow()
-step_sample <- function(recipe, ...,
+step_sample <- function(recipe,
+                        ...,
                         role = NA,
                         trained = FALSE,
                         size = NULL,
@@ -170,9 +170,14 @@ print.step_sample <-
 #' @rdname tidy.recipe
 #' @export
 tidy.step_sample <- function(x, ...) {
-  tibble(
-    size = x$size,
-    replace = x$replace,
-    id = x$inputs
-  )
+  if (is.null(x$size)) {
+    res <- tibble(size = numeric(), replace = logical())
+  } else {
+    res <- tibble(
+      size = x$size,
+      replace = x$replace
+    )
+  }
+  res$id <- x$id
+  res
 }
