@@ -1,11 +1,10 @@
 #' Square Root Transformation
 #'
-#' `step_sqrt` creates a *specification* of a recipe
-#'  step that will square root transform the data.
+#' `step_sqrt()` creates a *specification* of a recipe step that will apply
+#' square root transform to the variables.
 #'
 #' @inheritParams step_center
-#' @param columns A character string of variable names that will
-#'  be populated (eventually) by the `terms` argument.
+#' @inheritParams step_pca
 #' @template step-return
 #' @family individual transformation steps
 #' @details
@@ -83,12 +82,13 @@ prep.step_sqrt <- function(x, training, info = NULL, ...) {
 
 #' @export
 bake.step_sqrt <- function(object, new_data, ...) {
-  check_new_data(names(object$columns), object, new_data)
+  col_names <- names(object$columns)
+  check_new_data(col_names, object, new_data)
 
-  col_names <- object$columns
-  for (i in seq_along(col_names)) {
-    new_data[[col_names[i]]] <- sqrt(new_data[[col_names[i]]])
+  for (col_name in col_names) {
+    new_data[[col_name]] <- sqrt(new_data[[col_name]])
   }
+
   new_data
 }
 
