@@ -7,19 +7,24 @@
 #'   `step_blah` or `check_blah` depending on the context.
 #' @param ... All arguments to the operator that should be returned.
 #' @param .prefix Prefix to the subclass created.
+#'
+#' @seealso [developer_functions]
+#'
 #' @keywords internal
 #' @return An updated step or check with the new class.
 #' @export
 step <- function(subclass, ..., .prefix = "step_") {
   structure(list(...),
-            class = c(paste0(.prefix, subclass), "step"))
+    class = c(paste0(.prefix, subclass), "step")
+  )
 }
 
 #' @rdname step
 #' @export
 check <- function(subclass, ..., .prefix = "check_") {
   structure(list(...),
-            class = c(paste0(.prefix, subclass), "check"))
+    class = c(paste0(.prefix, subclass), "check")
+  )
 }
 
 #' Add a New Operation to the Current Recipe
@@ -30,6 +35,9 @@ check <- function(subclass, ..., .prefix = "check_") {
 #' @param rec A [recipe()].
 #' @param object A step or check object.
 #' @return A updated [recipe()] with the new operation in the last slot.
+#'
+#' @seealso [developer_functions]
+#'
 #' @export
 add_step <- function(rec, object) {
   rec$steps[[length(rec$steps) + 1]] <- object
@@ -43,4 +51,3 @@ add_check <- function(rec, object) {
   rec$steps[[length(rec$steps) + 1]] <- object
   rec
 }
-
