@@ -97,6 +97,18 @@ test_that("tunable", {
   )
 })
 
+test_that("works when baked with 1 row", {
+  rec <- recipe(mpg ~ ., data = mtcars) %>%
+    step_bs(disp) %>%
+    prep()
+
+  expect_no_error(
+    res <- bake(rec, mtcars[1, ])
+  )
+
+  expect_identical(nrow(res), 1L)
+})
+
 # Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
