@@ -47,51 +47,19 @@ test_that("bad selector(s)", {
   )
 })
 
+test_that("check_name() is used", {
+  dat <- iris
 
-test_that("printing", {
-  rec1 <- rec %>%
-    step_regex(description, pattern = "(rock|stony)")
-  expect_snapshot(print(rec1))
-  expect_snapshot(prep(rec1))
+  rec <- recipe(~., data = dat) |>
+    step_regex(Species, result = "Sepal.Width")
+
+  expect_snapshot(
+    error = TRUE,
+    prep(rec, training = dat)
+  )
 })
 
-test_that("empty selection prep/bake adds a 0 column", {
-  rec1 <- recipe(mpg ~ ., mtcars)
-  rec2 <- step_regex(rec1, pattern = "xxx")
-
-  rec1 <- prep(rec1, mtcars)
-  rec2 <- prep(rec2, mtcars)
-
-  baked1 <- bake(rec1, mtcars)
-  baked2 <- bake(rec2, mtcars)
-
-  expect_identical(baked2$xxx, rep(0, nrow(mtcars)))
-})
-
-test_that("empty selection tidy method works", {
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_regex(rec)
-
-  expect <- tibble(terms = character(), result = character(), id = character())
-
-  expect_identical(tidy(rec, number = 1), expect)
-
-  rec <- prep(rec, mtcars)
-
-  expect_identical(tidy(rec, number = 1), expect)
-})
-
-test_that("empty printing", {
-  skip_if(packageVersion("rlang") < "1.0.0")
-  rec <- recipe(mpg ~ ., mtcars)
-  rec <- step_regex(rec)
-
-  expect_snapshot(rec)
-
-  rec <- prep(rec, mtcars)
-
-  expect_snapshot(rec)
-})
+# Infrastructure ---------------------------------------------------------------
 
 test_that("bake method errors when needed non-standard role columns are missing", {
   mt_tibble <- mtcars %>%
@@ -107,3 +75,92 @@ test_that("bake method errors when needed non-standard role columns are missing"
   expect_error(bake(rec, new_data = mt_tibble[, c(-1)]),
                class = "new_data_missing_column")
 })
+
+test_that("empty printing", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_regex(rec)
+
+  expect_snapshot(rec)
+
+  rec <- prep(rec, mtcars)
+
+  expect_snapshot(rec)
+})
+
+test_that("empty selection prep/bake is a no-op", {
+  rec1 <- recipe(mpg ~ ., mtcars)
+  rec2 <- step_regex(rec1)
+
+  rec1 <- prep(rec1, mtcars)
+  rec2 <- prep(rec2, mtcars)
+
+  baked1 <- bake(rec1, mtcars)
+  baked2 <- bake(rec2, mtcars)
+
+  expect_identical(baked1, baked2)
+})
+
+test_that("empty selection tidy method works", {
+  rec <- recipe(mpg ~ ., mtcars)
+  rec <- step_regex(rec)
+
+  expect <- tibble(terms = character(), result = character(), id = character())
+
+  expect_identical(tidy(rec, number = 1), expect)
+
+  rec <- prep(rec, mtcars)
+
+  expect_identical(tidy(rec, number = 1), expect)
+})
+
+test_that("keep_original_cols works", {
+  new_names <- c("rocks")
+
+  rec <-  recipe(~ description, covers) %>%
+    step_regex(description, pattern = "(rock|stony)", result = "rocks",
+               keep_original_cols = FALSE)
+
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
+
+  expect_equal(
+    colnames(res),
+    new_names
+  )
+
+  rec <- recipe(~ description, covers) %>%
+    step_regex(description, pattern = "(rock|stony)", result = "rocks",
+               keep_original_cols = TRUE)
+
+  rec <- prep(rec)
+  res <- bake(rec, new_data = NULL)
+
+  expect_equal(
+    colnames(res),
+    c("description", new_names)
+  )
+})
+
+test_that("keep_original_cols - can prep recipes with it missing", {
+  rec <- recipe(~ description, covers) %>%
+    step_regex(description, pattern = "(rock|stony)")
+
+  rec$steps[[1]]$keep_original_cols <- NULL
+
+  expect_snapshot(
+    rec <- prep(rec)
+  )
+
+  expect_error(
+    bake(rec, new_data = covers),
+    NA
+  )
+})
+
+test_that("printing", {
+  rec <- recipe(~ description + rows + ch_rows, covers) %>%
+    step_regex(description, pattern = "(rock|stony)")
+
+  expect_snapshot(print(rec))
+  expect_snapshot(prep(rec))
+})
